Alexis' log - Alexis Métaireau

3. # Oh yeah !

   ## Why not ?

   After all, why not ? It's pretty simple to do it, and it will allow me to write my blogposts in rst ! YEAH !

   read more

   There are comments.

4. # Second article

   This is some article, in english

   read more

   There are comments.

5. # This is a super article !

   Multi-line metadata should be supported as well as inline markup.

   read more

   There are comments.

6. # Unbelievable !

   Or completely awesome. Depends the needs.

   read more

   There are comments.

« Page 2 / 2

## blogroll

- Biologeek
- Filyb
- Libert-fr
- N1k0
- Tarek Ziadé
- Zubin Mithra

## social

- atom feed
- rss feed
- twitter
- lastfm
- github